# Tomography Analysis Tool

A tool for 2D tomographic images clustering using the k-means method.

## Dependencies

- [PySide6](https://pypi.org/project/PySide6/)
    - [API reference](https://doc.qt.io/qtforpython-6/modules.html)
- [numpy](https://pypi.org/project/numpy/)
    - [API reference](https://numpy.org/doc/stable/reference/index.html)
- [opencv](https://pypi.org/project/opencv-python/)
    - [API reference](https://docs.opencv.org/master/index.html)
- [Pillow](https://pypi.org/project/Pillow/)
    - [API reference](https://pillow.readthedocs.io/en/stable/reference/index.html)
- [scikit-image](https://pypi.org/project/scikit-image/)
    - [API reference](https://scikit-image.org/docs/stable/api/api.html)
- [scikit-learn](https://pypi.org/project/scikit-learn/)
    - [API reference](https://scikit-learn.org/stable/modules/classes.html)
- [matplotlib](https://pypi.org/project/matplotlib/)
    - [API reference](https://matplotlib.org/stable/api/index.html)

## Install

This application is available on [PyPi](https://pypi.org/project/tat/). You can install it using the `pip` tool.

```bash
pip install tat
```

## Usage

You can use the command line to run the application. An installer for windows will be released.

e.g.

```bash
python -m tat
```